@@ -2,6 +2,7 @@ import base64
 import json
 import os
 import requests as req
+from urllib3 import encode_multipart_formdata
 
 
 
@@ -193,29 +194,38 @@ class AkeneoConnector:
             data = response.text
             
         return data
-
-    def upload_media(self, product_dict: dict, media_file: str):
+    def upload_media(self, product_dict: dict, file_path: str):
         """
         Uploads media to Akeneo.
 
         Args:
             product_dict (dict): The product info to send in the request.
-            media_file (str): The base64 encoded the media file.
+            file_path (str): The path to the local media file.
         """
-        # Convert to JSON-string
-        data_str = json.dumps({
-            'product': product_dict,
-            'file': media_file	
-        })
 
-        # Set the payload to the JSON-string
-        print(f"POST {self.products_media_url}")
-        headers = {
-            'Authorization': 'Bearer ' + self.access_token,
-            'Content-type': 'multipart/form-data'
+        # Infer filename and file type from path
+        binary = open(file_path, 'rb').read()
+        filename = os.path.basename(file_path)
+        file_type = 'image/jpeg' if filename.endswith('.jpg') else 'application/pdf'
+
+        # Create fields
+        fields = {
+            "product": json.dumps(product_dict),
+            "file": (filename, binary, file_type)
         }
-        
-        response = req.post(self.products_media_url, headers=headers, data=data_str)
+
+        # Encode body and header
+        encoded_body, content_type = encode_multipart_formdata(fields)
+
+        # Add authorization
+        headers = {
+            'Content-Type': content_type,
+            'Authorization': 'Bearer ' + self.access_token,
+        }
+
+        # Send the request to the Akeneo API
+        print(f"POST {self.products_media_url}")
+        response = req.post(self.products_media_url, headers=headers, data=encoded_body)
 
         # Check if the request was successful
         if response.status_code < 200 or response.status_code >= 300:
